@@ -577,6 +577,7 @@ bool Smb4KConfigDialog::writeSuperUserEntries()
 
   // Check if we need to write anything at all:
   Smb4KFileIO::Operation op = Smb4KFileIO::NoOperation;
+  bool success = true;
 
 #ifdef __linux__
   if ( sudo && super && force && full_use )
@@ -597,7 +598,7 @@ bool Smb4KConfigDialog::writeSuperUserEntries()
            (full_use->isChecked() && always_use_su != full_use->isChecked())) )
 #endif
       {
-        Smb4KCore::fileIO()->writeSudoers( (op = Smb4KFileIO::Insert) );
+        success = Smb4KCore::fileIO()->writeSudoers( (op = Smb4KFileIO::Insert) );
       }
     }
     else if ( super->isChecked() )
@@ -613,7 +614,7 @@ bool Smb4KConfigDialog::writeSuperUserEntries()
            (full_use->isChecked() && always_use_su != full_use->isChecked())) )
 #endif
       {
-        Smb4KCore::fileIO()->writeSuperTab( (op = Smb4KFileIO::Insert) );
+        success = Smb4KCore::fileIO()->writeSuperTab( (op = Smb4KFileIO::Insert) );
       }
     }
     else
@@ -633,7 +634,7 @@ bool Smb4KConfigDialog::writeSuperUserEntries()
     // Do nothing
   }
 
-  return (op == Smb4KFileIO::NoOperation) ? false : true;
+  return (!success || op == Smb4KFileIO::NoOperation) ? false : true;
 }
 
 
