@@ -249,7 +249,7 @@ Smb4KSambaOptions::Smb4KSambaOptions( QWidget *parent, const char *name )
   advanced_smbfs->setInsideSpacing( 5 );
 
   (void) new QCheckBox( i18n( "Use Unicode when communicating with the server" ), advanced_smbfs, "kcfg_UnicodeSupport" );
-  (void) new QCheckBox( i18n( "Use large file system support" ), advanced_smbfs, "kcfg_LargeFileSystemSupport" );
+  (void) new QCheckBox( i18n( "Use large file support" ), advanced_smbfs, "kcfg_LargeFileSystemSupport" );
 
   QWidget *s_advanced_widget =  new QWidget( advanced_smbfs );
   QGridLayout *s_advanced_layout = new QGridLayout( s_advanced_widget );
