@@ -3,8 +3,8 @@
     authentication data.
                              -------------------
     begin                : Sa Feb 28 2004
-    copyright            : (C) 2004 by Alexander Reinholdt
-    email                : dustpuppy@mail.berlios.de
+    copyright            : (C) 2004-2007 by Alexander Reinholdt
+    email                : dustpuppy@users.berlios.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -54,7 +54,11 @@ class Smb4KAuthInfo
      *
      * @param password  The password that's used for authentication. Default is QString::null.
      */
-    Smb4KAuthInfo( const QString &workgroup, const QString &host, const QString &share, const QString &user = QString::null, const QString &password = QString::null );
+    Smb4KAuthInfo( const QString &workgroup,
+                   const QString &host,
+                   const QString &share,
+                   const QString &user = QString::null,
+                   const QString &password = QString::null );
     /**
      * The empty constructor.
      */
