@@ -38,6 +38,7 @@
 #include <kpassivepopup.h>
 #include <kdebug.h>
 #include <kstaticdeleter.h>
+#include <dcopclient.h>
 
 // system includes
 #include <stdlib.h>
@@ -143,6 +144,7 @@ Smb4KCore *Smb4KCore::self()
 
 void Smb4KCore::init()
 {
+  // Start the core.
   m_scanner->init();
   m_mounter->init();
 }
