@@ -93,9 +93,6 @@ Smb4KMounter::Smb4KMounter( QObject *parent, const char *name ) : QObject( paren
   connect( m_proc,  SIGNAL( receivedStderr( KProcess *, char *, int ) ),
            this,    SLOT( slotReceivedStderr( KProcess *, char *, int ) ) );
 
-  connect( timer(), SIGNAL( timeout() ),
-           this,    SLOT( slotProcessQueue() ) );
-
   connect( kapp,    SIGNAL( shutDown() ),
            this,    SLOT( slotShutdown() ) );
 }
@@ -120,6 +117,8 @@ void Smb4KMounter::init()
 {
   m_queue.enqueue( new QString( QString( "%1:" ).arg( Import ) ) );
   m_queue.enqueue( new QString( QString( "%1:" ).arg( Remount ) ) );
+
+  startTimer( TIMER_INTERVAL );
 }
 
 
@@ -303,7 +302,7 @@ void Smb4KMounter::import()
 
         if ( (*it).contains( " smbfs ", false ) != 0 )
         {
-          QString share_and_path = (*it).section( "smbfs", 0, 0 ).stripWhiteSpace();
+          QString share_and_path = (*it).section( " smbfs ", 0, 0 ).stripWhiteSpace();
           QString name = share_and_path.section( " ", 0, 0 ).stripWhiteSpace().replace( "\\040", "\040" );
           QString path = share_and_path.section( " ", 1, 1 ).stripWhiteSpace();
 
@@ -320,7 +319,7 @@ void Smb4KMounter::import()
         }
         else if ( (*it).contains( " cifs ", false ) != 0 )
         {
-          QString share_and_path = (*it).section( "cifs", 0, 0 ).stripWhiteSpace();
+          QString share_and_path = (*it).section( " cifs ", 0, 0 ).stripWhiteSpace();
           QString name = share_and_path.section( " ", 0, 0 ).stripWhiteSpace().replace( "\\040", "\040" );
           QString path = share_and_path.section( " ", 1, 1 ).stripWhiteSpace();
 
@@ -1475,30 +1474,7 @@ void Smb4KMounter::checkAccessibility( Smb4KShare *share )
 }
 
 
-/////////////////////////////////////////////////////////////////////////////
-// SLOT IMPLEMENTATIONS
-/////////////////////////////////////////////////////////////////////////////
-
-
-void Smb4KMounter::slotProcessExited( KProcess * )
-{
-  endProcess();
-}
-
-
-void Smb4KMounter::slotReceivedStdout( KProcess *, char *buf, int len )
-{
-  m_buffer.append( QString::fromLocal8Bit( buf, len ) );
-}
-
-
-void Smb4KMounter::slotReceivedStderr( KProcess *, char *buf, int len )
-{
-  m_buffer.append( QString::fromLocal8Bit( buf, len ) );
-}
-
-
-void Smb4KMounter::slotProcessQueue()
+void Smb4KMounter::timerEvent( QTimerEvent * )
 {
   if ( !m_working && !m_queue.isEmpty() )
   {
@@ -1557,6 +1533,29 @@ void Smb4KMounter::slotProcessQueue()
 }
 
 
+/////////////////////////////////////////////////////////////////////////////
+// SLOT IMPLEMENTATIONS
+/////////////////////////////////////////////////////////////////////////////
+
+
+void Smb4KMounter::slotProcessExited( KProcess * )
+{
+  endProcess();
+}
+
+
+void Smb4KMounter::slotReceivedStdout( KProcess *, char *buf, int len )
+{
+  m_buffer.append( QString::fromLocal8Bit( buf, len ) );
+}
+
+
+void Smb4KMounter::slotReceivedStderr( KProcess *, char *buf, int len )
+{
+  m_buffer.append( QString::fromLocal8Bit( buf, len ) );
+}
+
+
 void Smb4KMounter::slotShutdown()
 {
   // Abort any action:
