@@ -227,6 +227,11 @@ class Smb4KMounter : public QObject
      */
     void processUnmount();
 
+    /**
+     * Reimplemented from QObject
+     */
+    void timerEvent( QTimerEvent *e );
+
   protected slots:
     /**
      * Is called, when the process exits.
@@ -243,11 +248,6 @@ class Smb4KMounter : public QObject
      */
     void slotReceivedStderr( KProcess *, char *buf, int len );
 
-    /**
-     * Initiates the processing of the queue.
-     */
-    void slotProcessQueue();
-
     /**
      * This slot is called by the KApplication::shutDown() signal.
      * Is does everything that has to be done before the program
