@@ -26,143 +26,160 @@
 
 // KDE includes
 #include <klocale.h>
+#include <ksocketaddress.h>
 
 // application specific includes
 #include "smb4knetworkitems.h"
 
 
 /****************************************************************************
-   Constructor for the Smb4KWorkgroupItem class.
+   Smb4KWorkgroupItem class
 ****************************************************************************/
 
 Smb4KWorkgroupItem::Smb4KWorkgroupItem( const QString &name, const QString &master, const QString &masterIP )
-: m_name( name ), m_master( master ), m_ip( masterIP )
+: m_name( name ), m_master( master ), m_pseudo( false )
 {
-  m_pseudo = false;
+  m_ip = ipIsValid( masterIP ) ? masterIP : QString::null;
 }
 
-/****************************************************************************
-   Destructor for the Smb4KWorkgroupItem class.
-****************************************************************************/
 
 Smb4KWorkgroupItem::~Smb4KWorkgroupItem()
 {
 }
 
 
-/****************************************************************************
-   Set the pseudo value to TRUE.
-****************************************************************************/
-
-void Smb4KWorkgroupItem::setPseudo()
+void Smb4KWorkgroupItem::setPseudoMaster()
 {
   m_pseudo = true;
 }
 
 
-/****************************************************************************
-  Sets the master's IP address
-****************************************************************************/
-
-void Smb4KWorkgroupItem::setMasterIPAddress( const QString &ip )
+void Smb4KWorkgroupItem::setMasterIP( const QString &ip )
 {
-  m_ip = ip;
+  m_ip = ipIsValid( ip ) ? ip : QString::null;
+}
+
+
+void Smb4KWorkgroupItem::setMaster( const QString &name, const QString &ip, bool pseudo )
+{
+  m_master = name;
+  m_ip = ipIsValid( ip ) ? ip : QString::null;
+  m_pseudo = pseudo;
+}
+
+
+bool Smb4KWorkgroupItem::ipIsValid( const QString &ip )
+{
+  if ( !ip.isEmpty() )
+  {
+    KNetwork::KIpAddress ip_address = KNetwork::KIpAddress( ip );
+
+    if ( !ip_address.isIPv4Addr() && !ip_address.isIPv6Addr() )
+    {
+      return false;
+    }
+  }
+  else
+  {
+    return false;
+  }
+
+  return true;
 }
 
 
 /****************************************************************************
-   Constructors for the Smb4KHostItem class.
+   Smb4KHostItem class
 ****************************************************************************/
 
 Smb4KHostItem::Smb4KHostItem( const QString &workgroup, const QString &name, const QString &comment, const QString &ip )
-: m_workgroup( workgroup ), m_name( name ), m_comment( comment ), m_ip( ip ), m_master( false ),
+: m_workgroup( workgroup ), m_name( name ), m_comment( comment ), m_server_string( QString::null ),
+  m_os_string( QString::null ), m_master( false ), m_ip_checked( m_ip.stripWhiteSpace().isEmpty() ? false : true ),
   m_info_checked( false )
 {
-  m_ip_checked = m_ip.stripWhiteSpace().isEmpty() ? false : true;
+  m_ip = ipIsValid( ip ) ? ip : QString::null;
 }
 
 
-/****************************************************************************
-   Destructor for the Smb4KHostItem class.
-****************************************************************************/
+Smb4KHostItem::Smb4KHostItem( const Smb4KHostItem &host )
+: m_workgroup( host.workgroup() ), m_name( host.name() ), m_comment( host.comment() ), m_ip( host.ip() ),
+  m_server_string( host.serverString() ), m_os_string( host.osString() ), m_master( host.isMaster() ),
+  m_ip_checked( host.ipAddressChecked() ), m_info_checked( host.infoChecked() )
+{
+  // NOTE: We do not check the IP address here, because that has
+  // already been done by the copied Smb4KHostItem object.
+}
+
 
 Smb4KHostItem::~Smb4KHostItem()
 {
 }
 
 
-/****************************************************************************
-  Sets the server string of this host.
-****************************************************************************/
-
 void Smb4KHostItem::setServerString( const QString &server )
 {
   m_server_string = server;
 }
 
 
-/****************************************************************************
-  Sets the OS string of this host.
-****************************************************************************/
-
 void Smb4KHostItem::setOSString( const QString &os )
 {
   m_os_string = os;
 }
 
 
-/****************************************************************************
-   Determines if this host is a master browser
-****************************************************************************/
-
 void Smb4KHostItem::setMaster( bool master )
 {
   m_master = master;
 }
 
 
-/****************************************************************************
-   Sets the IP address
-****************************************************************************/
-
 void Smb4KHostItem::setIPAddress( const QString &ip )
 {
-  m_ip = ip;
+  m_ip = ipIsValid( ip ) ? ip : QString::null;
 }
 
 
-/****************************************************************************
-   Sets the comment
-****************************************************************************/
-
 void Smb4KHostItem::setComment( const QString &comment )
 {
   m_comment = comment;
 }
 
 
-/****************************************************************************
-   Used if one has checked for the IP address.
-****************************************************************************/
-
 void Smb4KHostItem::setIPAddressChecked( bool yes )
 {
   m_ip_checked = yes;
 }
 
 
-/****************************************************************************
-   Used if one has checked for the information
-****************************************************************************/
-
 void Smb4KHostItem::setInfoChecked( bool yes )
 {
   m_info_checked = yes;
 }
 
 
+bool Smb4KHostItem::ipIsValid( const QString &ip )
+{
+  if ( !ip.isEmpty() )
+  {
+    KNetwork::KIpAddress ip_address = KNetwork::KIpAddress( ip );
+
+    if ( !ip_address.isIPv4Addr() && !ip_address.isIPv6Addr() )
+    {
+      return false;
+    }
+  }
+  else
+  {
+    return false;
+  }
+
+  return true;
+}
+
+
 /****************************************************************************
-   Constructor for the Smb4KShareItem class.
+   Smb4KShareItem class
 ****************************************************************************/
 
 Smb4KShareItem::Smb4KShareItem( const QString &workgroup, const QString &host, const QString &name, const QString &type, const QString &comment )
@@ -171,19 +188,11 @@ Smb4KShareItem::Smb4KShareItem( const QString &workgroup, const QString &host, c
 }
 
 
-/****************************************************************************
-   Destructor for the Smb4KShareItem class.
-****************************************************************************/
-
 Smb4KShareItem::~Smb4KShareItem()
 {
 }
 
 
-/****************************************************************************
-   Returns a translated version of the share type
-****************************************************************************/
-
 const QString Smb4KShareItem::translatedType() const
 {
   QString return_string;
@@ -205,30 +214,26 @@ const QString Smb4KShareItem::translatedType() const
 }
 
 
-/****************************************************************************
-   Constructor for the Smb4KPreviewItem class.
-****************************************************************************/
-
-Smb4KPreviewItem::Smb4KPreviewItem( const QString &host, const QString &share, const QString &path, const QString &name, bool file )
-: m_host( host ), m_share( share ), m_path( path ), m_name( name ), m_isFile( file )
+bool Smb4KShareItem::isHidden() const
 {
+  return m_name.stripWhiteSpace().endsWith( "$" );
 }
 
 
-/****************************************************************************
-   Destructor for the Smb4KPreviewItem class.
-****************************************************************************/
-
-Smb4KPreviewItem::~Smb4KPreviewItem()
+bool Smb4KShareItem::isPrinter() const
 {
+  return (QString::compare( m_type, "Print" ) == 0 || QString::compare( m_type, "Printer" ) == 0);
 }
 
 
-/****************************************************************************
-   Sets the item to be a file or directory.
-****************************************************************************/
-
-void Smb4KPreviewItem::setIsFile( bool sw )
+bool Smb4KShareItem::isIPC() const
 {
-  m_isFile = sw;
+  return (QString::compare( m_name.stripWhiteSpace(), "IPC$" ) == 0);
 }
+
+
+bool Smb4KShareItem::isADMIN() const
+{
+  return (QString::compare( m_name.stripWhiteSpace(), "ADMIN$" ) == 0);
+}
+
