@@ -36,7 +36,7 @@
 #include <qstring.h>
 
 /**
- * This class provides a container for a workgroup found in the network
+ * This class provides a container for a workgroup/domain found in the network
  * neighborhood.
  */
 
@@ -45,8 +45,16 @@ class Smb4KWorkgroupItem
   public:
     /**
      * The constructor.
+     *
+     * @param name        The name of the workgroup/domain.
+     *
+     * @param master      The master browser of the workgroup.
+     *
+     * @param masterIP    The IP address of the workgroup master browser.
      */
-    Smb4KWorkgroupItem( const QString &name, const QString &master, const QString &masterIP = QString::null );
+    Smb4KWorkgroupItem( const QString &name,
+                        const QString &master,
+                        const QString &masterIP = QString::null );
 
     /**
      * Empty constructor.
@@ -61,7 +69,7 @@ class Smb4KWorkgroupItem
     /**
      * Returns the workgroup name.
      */
-    const QString &workgroup() const { return m_name; }
+    const QString &name() const { return m_name; }
 
     /**
      * Returns the name of the master browser.
@@ -69,26 +77,47 @@ class Smb4KWorkgroupItem
     const QString &master() const { return m_master; }
 
     /**
-     * Returns the IP address of the master browser.
+     * Returns the IP address of the master browser. If it is not a valid
+     * IPv4 or IPv6 address, QString::null is returned.
+     *
+     * @returns the valid IP v4 or v6 address of the workgroup master browser
+     * or QString::null.
      */
-    const QString &ip() const { return m_ip; }
+    const QString &masterIP() const { return m_ip; }
 
     /**
-     * You can mark the master as 'pseudo' with this function.
+     * You can mark the master as 'pseudo' with this function. That means that
+     * this master was not reported as being the master browser of this
+     * workgroup, but it's the only one found (e.g. by a custom search).
      */
-    void setPseudo();
+    void setPseudoMaster();
 
     /**
-     * Returns TRUE, if the master is a 'pseudo'-master.
+     * Returns TRUE, if the master is a 'pseudo' master. @see setPseudoMaster()
+     * for further information.
      */
-    bool pseudo() const { return m_pseudo; }
+    bool hasPseudoMaster() const { return m_pseudo; }
 
     /**
      * This function sets the IP address of the master browser.
      *
      * @param ip            The IP address of the master browser
      */
-    void setMasterIPAddress( const QString &ip );
+    void setMasterIP( const QString &ip );
+
+    /**
+     * This function sets the master browser.
+     *
+     * @param name          The name of the master browser
+     *
+     * @param ip            The IP address of the master browser
+     *
+     * @param pseudo        Determines if this is a real master browser or if
+     *                      it is a faked one, i.e. a pseudo master.
+     */
+    void setMaster( const QString &name,
+                    const QString &ip,
+                    bool pseudo = false );
 
   private:
     /**
@@ -110,6 +139,17 @@ class Smb4KWorkgroupItem
      * Determines whether the master is a 'pseudo'-master.
      */
     bool m_pseudo;
+
+    /**
+     * This function checks if the IP address is valid, i.e. the
+     * IP address is either IP v4 or IP v6. It returns either TRUE
+     * or FALSE.
+     *
+     * @param ip            The IP address that's going to be checked.
+     *
+     * @returns TRUE if the IP address is valid and FALSE otherwise.
+     */
+    bool ipIsValid( const QString &ip );
 };
 
 
@@ -122,9 +162,27 @@ class Smb4KHostItem
 {
   public:
     /**
-     * The constructor.
+     * The default constructor.
+     *
+     * @param workgroup     The workgroup/domain of the host
+     *
+     * @param name          The name of the host
+     *
+     * @param comment       The comment that describes the host. May be empty.
+     *
+     * @param ip            The IP address of the host
      */
-    Smb4KHostItem( const QString &workgroup, const QString &name, const QString &comment = QString::null, const QString &ip = QString::null );
+    Smb4KHostItem( const QString &workgroup,
+                   const QString &name,
+                   const QString &comment = QString::null,
+                   const QString &ip = QString::null );
+
+    /**
+     * The copy constructor.
+     *
+     * @param host          A Smb4KHostItem representing a host.
+     */
+    Smb4KHostItem( const Smb4KHostItem &host );
 
     /**
      * The empty constructor.
@@ -189,7 +247,7 @@ class Smb4KHostItem
      *
      * @returns             TRUE if the host is a master browser.
      */
-    bool isMaster() { return m_master; }
+    const bool isMaster() const { return m_master; }
 
     /**
      * This function sets the IP address of a host.
@@ -218,7 +276,7 @@ class Smb4KHostItem
      *
      * @returns             TRUE if a check was performed, and FALSE otherwise.
      */
-    bool ipAddressChecked() { return m_ip_checked; }
+    const bool ipAddressChecked() const { return m_ip_checked; }
 
     /**
      * This function is used to tell the host item, if a
@@ -234,7 +292,7 @@ class Smb4KHostItem
      *
      * @returns             TRUE is the check was performed previously.
      */
-    bool infoChecked() { return m_info_checked; }
+    const bool infoChecked() const { return m_info_checked; }
 
   private:
     /**
@@ -284,6 +342,17 @@ class Smb4KHostItem
      * was already performed.
      */
     bool m_info_checked;
+
+    /**
+     * This function checks if the IP address is valid, i.e. the
+     * IP address is either IP v4 or IP v6. It returns either TRUE
+     * or FALSE.
+     *
+     * @param ip            The IP address that's going to be checked.
+     *
+     * @returns TRUE if the IP address is valid and FALSE otherwise.
+     */
+    bool ipIsValid( const QString &ip );
 };
 
 
@@ -297,8 +366,23 @@ class Smb4KShareItem
   public:
     /**
      * The constructor.
+     *
+     * @param workgroup         The workgroup/domain name.
+     *
+     * @param host              The name of the host where the share is located.
+     *
+     * @param name              The name of the share.
+     *
+     * @param type              The type of the share as returned by the Samba programs, i.e.
+     *                          "Disk", "Printer", "IPC$" or "ADMIN$".
+     *
+     * @param comment           The comment of the share.
      */
-    Smb4KShareItem( const QString &workgroup, const QString &host, const QString &name, const QString &type, const QString &comment );
+    Smb4KShareItem( const QString &workgroup,
+                    const QString &host,
+                    const QString &name,
+                    const QString &type,
+                    const QString &comment );
 
     /**
      * Empty constructor.
@@ -331,7 +415,7 @@ class Smb4KShareItem
     const QString &plainType() const { return m_type; }
 
     /**
-     * Returns a translated version of the type of the share. If
+     * Returns a translated version of the type of the share.
      *
      * @returns           The translated share type
      */
@@ -342,6 +426,37 @@ class Smb4KShareItem
      */
     const QString &comment() const { return m_comment; }
 
+    /**
+     * This function tells if the share is a hidden one.
+     *
+     * @returns           TRUE is the share is a hidden one and FALSE otherwise.
+     */
+    bool isHidden() const;
+
+    /**
+     * This function is TRUE if the share is a printer and
+     * FALSE otherwise.
+     *
+     * @returns	          TRUE if the share is a printer
+     */
+    bool isPrinter() const;
+
+    /**
+     * This function returns TRUE if the share is an IPC$
+     * share and FALSE otherwise.
+     *
+     * @returns           TRUE if the share is an IPC$ share
+     */
+    bool isIPC() const;
+
+    /**
+     * This function returns TRUE if the share is an ADMIN$
+     * share and FALSE otherwise.
+     *
+     * @returns           TRUE if the share is an ADMIN$ share
+     */
+    bool isADMIN() const;
+
   private:
     /**
      * The workgroup object.
@@ -369,73 +484,4 @@ class Smb4KShareItem
     QString m_comment;
 };
 
-
-/**
- * This class provides a container for the preview
- * of the contents of a share.
- */
-
-class Smb4KPreviewItem
-{
-  public:
-    /**
-     * The default constructor.
-     */
-    Smb4KPreviewItem( const QString &host, const QString &share, const QString &path, const QString &name, bool file = true );
-    /**
-     * The empty constructor.
-     */
-    Smb4KPreviewItem() {}
-    /**
-     * The destructor.
-     */
-    ~Smb4KPreviewItem();
-    /**
-     * Return the name of the host where the share is located.
-     */
-    const QString &host() const { return m_host; }
-    /**
-     * Return the name of the share that is to be previewed.
-     */
-    const QString &share() const { return m_share; }
-    /**
-     * Return the path that is to be previewed.
-     */
-    const QString &path() const { return m_path; }
-    /**
-     * Return the name of the item.
-     */
-    const QString &name() const { return m_name; }
-    /**
-     * Returns TRUE if this item is a file.
-     */
-    bool isFile() const { return m_isFile; }
-    /**
-     * Sets the item to be a file or a directory.
-     */
-    void setIsFile( bool sw );
-
-  private:
-    /**
-     * The host name.
-     */
-    QString m_host;
-    /**
-     * The share name.
-     */
-    QString m_share;
-    /**
-     * The path that has to be previewed.
-     */
-    QString m_path;
-    /**
-     * The name of the item.
-     */
-    QString m_name;
-    /**
-     * Determines whether this is a file or a directory.
-     */
-    bool m_isFile;
-};
-
 #endif
