@@ -42,6 +42,8 @@
 #include <klineedit.h>
 #include <kcombobox.h>
 #include <kdebug.h>
+#include <kapplication.h>
+#include <dcopclient.h>
 
 #ifdef __FreeBSD__
 #include <sys/stat.h>
@@ -59,10 +61,11 @@
 
 #ifndef __FreeBSD__
 Smb4KPasswordHandler::Smb4KPasswordHandler( Smb4KHomesSharesHandler *handler, QObject *parent, const char *name )
-: QObject( parent, name ), m_handler( handler )
+: QObject( parent, name ), m_handler( handler ), m_wallet_support_disabled( false )
 #else
 Smb4KPasswordHandler::Smb4KPasswordHandler( Smb4KHomesSharesHandler *s_handler, Smb4KSambaOptionsHandler *o_handler, QObject *parent, const char *name )
-: QObject( parent, name ), m_handler( s_handler ), m_options_handler( o_handler )
+: QObject( parent, name ), m_handler( s_handler ), m_options_handler( o_handler ),
+  m_wallet_support_disabled( false )
 #endif
 {
   if ( !m_handler )
@@ -99,10 +102,22 @@ Smb4KPasswordHandler::~Smb4KPasswordHandler()
 
 void Smb4KPasswordHandler::open_close_wallet()
 {
-  if ( Smb4KSettings::useWallet() )
+  if ( Smb4KSettings::useWallet() && !walletSupportIsDisabled() )
   {
     if ( !walletIsOpen() )
     {
+      // Start the wallet manager before accessing the wallet. We
+      // do not care about the return value, because we do not do
+      // error handling here.
+      if ( kapp )
+      {
+        (void) kapp->kdeinitExec( "kwalletmanager" );
+      }
+      else
+      {
+        // Do nothing. --- Good luck!
+      }
+
       m_wallet = KWallet::Wallet::openWallet( KWallet::Wallet::NetworkWallet(), 0, KWallet::Wallet::Synchronous );
 
       if ( m_wallet )
@@ -126,8 +141,7 @@ void Smb4KPasswordHandler::open_close_wallet()
         delete m_wallet;
         m_wallet = NULL;
 
-        Smb4KSettings::setUseWallet( false );
-        Smb4KSettings::writeConfig();
+        m_wallet_support_disabled = true;
       }
     }
     else
