@@ -179,6 +179,14 @@ class Smb4KPasswordHandler : public QObject
      */
     bool walletIsOpen() { return (m_wallet && m_wallet->isOpen()); }
 
+    /**
+     * This function returns TRUE if the digital wallet support has been
+     * disabled. This happens when the wallet could not be opened.
+     *
+     * @returns TRUE if the digital wallet support has been disabled.
+     */
+    bool walletSupportIsDisabled() { return m_wallet_support_disabled; }
+
   protected slots:
     /**
      * Get the password for a specific share and user name.
@@ -259,6 +267,11 @@ class Smb4KPasswordHandler : public QObject
      */
     Smb4KHomesSharesHandler *m_handler;
 
+    /**
+     * Is the wallet support disabled?
+     */
+    bool m_wallet_support_disabled;
+
 #ifdef __FreeBSD__
 
     /**
